/**
 * Licensed to Jasig under one or more contributor license
 * agreements. See the NOTICE file distributed with this work
 * for additional information regarding copyright ownership.
 * Jasig licenses this file to you under the Apache License,
 * Version 2.0 (the "License"); you may not use this file
 * except in compliance with the License. You may obtain a
 * copy of the License at:
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.jasig.portal.tools.checks;

import java.text.DateFormat;
import java.util.Date;

/**
 * An example ICheck implementation which is just a diagnostic and not an assertion.
 * This check cannot fail, but it still exposes useful information, namely when the check
 * was run.  When included in a batch of checks, allows you to see when the batch
 * was run.
 * 
 * @version $Revision: 19776 $ $Date: 2010-01-14 16:17:21 -0600 (Thu, 14 Jan 2010) $
 * @since uPortal 2.5
 */
public class TimeCheck 
    implements ICheck {

    public CheckResult doCheck() {
        
        String dateTime = DateFormat.getDateTimeInstance().format(new Date());
        return CheckResult.createSuccess("Check ran at " + dateTime);
    }

    public String getDescription() {
        return "This check reports the date and time at which it is run.";
    }

}

